REGISTER_ACTIONS (action_action_list)
REGISTER_ACTIONS (rotate_action_list)
REGISTER_ACTIONS (create_action_list)
REGISTER_FLAGS (djopt_flag_list)
REGISTER_ACTIONS (djopt_action_list)
REGISTER_ACTIONS (flag_action_list)
REGISTER_FLAGS (flags_flag_list)
REGISTER_ACTIONS (fontmode_action_list)
REGISTER_ACTIONS (layerflags_action_list)
REGISTER_ATTRIBUTES (main_attribute_list)
REGISTER_ACTIONS (misc_action_list)
REGISTER_ACTIONS (move_action_list)
REGISTER_ACTIONS (netlist_action_list)
REGISTER_ACTIONS (puller_action_list)
REGISTER_ACTIONS(relocate_action_list)
REGISTER_ACTIONS (renumber_block_action_list)
REGISTER_ACTIONS (report_action_list)
REGISTER_ACTIONS (set_action_list)
REGISTER_ACTIONS (smartdisperse_action_list)
REGISTER_ACTIONS (teardrops_action_list)
REGISTER_ACTIONS (vendor_action_list)
REGISTER_FLAGS (vendor_flag_list)
REGISTER_ACTIONS (toporouter_action_list)
REGISTER_ACTIONS (drc_action_list)
